package WebGUI::i18n::German::Account;
use utf8;
our $I18N = {
  'Error: Cannot instantiate template' => {
    'lastUpdated' => '1233558908',
    'message' => 'Fehler: Kann keine Instanz der Vorlage %s für die Klasse %s bilden!'
  },
  'Return to Account' => {
    'lastUpdated' => '1315987665',
    'message' => 'Zurück zur Übersicht'
  },
  'account className' => {
    'lastUpdated' => '1233774713',
    'message' => 'Der Perl-Klassenname für dieses Konto-Plugin.'
  },
  'account identifier' => {
    'lastUpdated' => '1233560395',
    'message' => 'Der Bezeichner für dieses Konto-Plugin laut Konfigurationsdatei. Die standardmäßig verfügbaren Bezeichner sind "profile", "inbox", "friends", "contributions", "shop" und "user".'
  },
  'account layout template' => {
    'lastUpdated' => '1233940825',
    'message' => 'Benutzerkonto, Layout'
  },
  'account title' => {
    'lastUpdated' => '1233560415',
    'message' => 'Der Titel dieses Konto-Plugins laut Konfigurationsdatei. Das Feld erlaubt die Verwendung von Makros.'
  },
  'account url' => {
    'lastUpdated' => '1233560544',
    'message' => 'Der URL zur Ansicht dieses Konto-Plugins.'
  },
  'account_loop' => {
    'lastUpdated' => '1233776129',
    'message' => 'Eine Schleife mit Information über alle verfügbaren Konto-Plugins.'
  },
  'back_url' => {
    'lastUpdated' => '1233559366',
    'message' => 'Der URL zum Verlassen der Konto-Ansicht zurück zur Seite.'
  },
  'common account variables' => {
    'lastUpdated' => '1233559392',
    'message' => 'Benutzerkonto, allgemeine Variablen'
  },
  'is_[[IDENTIFIER]]' => {
    'lastUpdated' => '1233560115',
    'message' => '[[IDENTIFIER]] wird durch die Bezeichner aller verfügbaren Plugins ersetzt. Die Variable für das aktuelle Plugin ist jeweils wahr.'
  },
  'is_active' => {
    'lastUpdated' => '1233560485',
    'message' => 'Eine Variable die wahr ist, falls dieses Konto-Plugin gerade angezeigt wird.'
  },
  'is_method_[[METHOD]]' => {
    'lastUpdated' => '1233560369',
    'message' => '[[METHOD]] wird durch die Namen der Standardansichten aller verfügbaren Plugins ersetzt (Der Vorgabewert ist "view").'
  },
  'profile_user_id' => {
    'lastUpdated' => '1344184481',
    'message' => 'Die userId des Benutzers dessen Account betrachtet wird.'
  },
  'root_url' => {
    'lastUpdated' => '1233559459',
    'message' => 'Der URL zur Hauptansicht des Kontos.'
  },
  'user_full_name' => {
    'lastUpdated' => '1344184446',
    'message' => 'Der vollständige Name des Benutzers dessen Account betrachtet wird.'
  },
  'user_member_since' => {
    'lastUpdated' => '1233559552',
    'message' => 'Das Erstellungsdatum in "Epoch"-Format für das aktuelle Konto. Der Wert kann mittels des "Date"-Makros formatiert werden.'
  },
  'view_profile_url' => {
    'lastUpdated' => '1233559569',
    'message' => 'Der URL zur Ansicht des Benutzerprofils.'
  }
}
;

1;
